{{/*
Полное имя приложения создается по правилу <имя helm-charts>-<имя инстанса>
<Имя инстанса> = Release.Name
*/}}
{{- define "activemq.fullname" -}}
{{- printf "%s-%s" .Chart.Name .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "activemq.labels" -}}
helm.sh/chart: {{ include "activemq.chart" . }}
{{ include "activemq.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "activemq.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "activemq.selectorLabels" -}}
app.kubernetes.io/instance: {{ .Release.Name }}
app: {{ include "activemq.fullname" . }}
{{- end }}

{{/*
ServiceAccount задается для контейнеров activemq-artemis, которые должны работать в кластерном режиме
*/}}
{{- define "activemq.serviceAccountName" -}}
{{- default (printf "%s-%s" .Values.serviceAccount.name .Release.Name) }}
{{- end }}

{{/*
Имя configMap jms artemis
*/}}
{{- define "activemq.activemq-config" -}}
{{- printf "%s-%s" (include "activemq.serviceAccountName" .) "config" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Имя configMap для кластера jgroups
*/}}
{{- define "activemq.jgroups-config" -}}
{{- printf "%s-%s-%s" "jgroups" .Chart.Name "config" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Return  the proper Storage Class
*/}}
{{- define "activemq.storageClass" -}}
  {{- if .Values.persistence.storageClass -}}
      {{- if (eq "-" .Values.persistence.storageClass) -}}
          {{- printf "storageClassName: \"\"" -}}
      {{- else }}
          {{- printf "storageClassName: %s" .Values.persistence.storageClass -}}
      {{- end -}}
  {{- end -}}
{{- end -}}

{{/*
Return  the name of secret credential for private registry
*/}}
{{- define "activemq.imagePullSecrets" -}}
  {{- if .Values.image.imagePullSecrets }}
imagePullSecrets:
    {{- range .Values.image.imagePullSecrets }}
  - name: {{ . }}
    {{- end }}
  {{- end }}
{{- end -}}

{{/*
Задаем replica
*/}}

{{- define "activemq.replicaQuote" -}}

{{- if eq .Values.global.replicaQuote.quoteClass "large" -}}
  {{- .Values.replicaCount.largeQuota_activemq -}}
{{- else -}}
  {{- if eq .Values.global.replicaQuote.quoteClass "middle" -}}
    {{- .Values.replicaCount.middleQuota_activemq -}}
  {{- else -}}
    {{- .Values.replicaCount.miniQuota_activemq -}}
  {{- end -}}
{{- end -}}

{{- end -}}

